@@ -4,10 +4,6 @@ import json
 from pathlib import Path
 from typing import Optional
 
-from PyQt5.QtCore import Qt, pyqtSignal
-from PyQt5.QtGui import QCloseEvent
-from PyQt5.QtWidgets import QDialog, QLineEdit, QVBoxLayout, QPushButton, QLabel, QFrame, QTabWidget, QMessageBox, \
-    QAction, QInputDialog, QWidget
 from feeluown.app.gui_app import GuiApp
 from feeluown.gui import ProviderUiManager
 from feeluown.gui.provider_ui import AbstractProviderUi, NavBtn
@@ -20,8 +16,14 @@ from fuo_bilibili import __identifier__, __alias__, BilibiliProvider
 from fuo_bilibili.api.schema.requests import PasswordLoginRequest, SendSmsCodeRequest, SmsCodeLoginRequest
 from fuo_bilibili.api.schema.responses import RequestLoginKeyResponse
 from fuo_bilibili.geetest.server import GeetestAuthServer
+from fuo_bilibili.qt_compat import (
+    pyqtSignal, QCloseEvent, RichText, TextBrowserInteraction,
+    QDialog, QLineEdit, QVBoxLayout, QPushButton, QLabel, QFrame, QTabWidget, QMessageBox,
+    QAction, QInputDialog, QWidget
+)
 from fuo_bilibili.util import rsa_encrypt, get_random_available_port
 from fuo_bilibili.const import PLUGIN_API_COOKIEDICT_FILE
+from fuo_bilibili.login import load_user_cookies, dump_user_cookies
 
 logger = logging.getLogger(__name__)
 
@@ -47,18 +49,10 @@ class LoginDialog(CookiesLoginDialog):
         return user
 
     def load_user_cookies(self):
-        if PLUGIN_API_COOKIEDICT_FILE.exists():
-            with PLUGIN_API_COOKIEDICT_FILE.open('r', encoding='utf-8') as f:
-                try:
-                    cookie_dict = json.load(f)
-                except Exception:
-                    logger.warning('parse cookies(json) failed')
-                    return None
-            return cookie_dict
+        return load_user_cookies()
 
     def dump_user_cookies(self, _, cookies):
-        with PLUGIN_API_COOKIEDICT_FILE.open('w', encoding='utf-8') as f:
-            json.dump(cookies, f, indent=2)
+        return dump_user_cookies(cookies)
 
 
 class BAuthDialog(QDialog):
@@ -120,8 +114,8 @@ class BAuthDialog(QDialog):
     def _create_link_label(self, link: str, text: str) -> QLabel:
         auth_link = QLabel(self)
         auth_link.setText(f'<a href="{link}">{text}</a>')
-        auth_link.setTextFormat(Qt.RichText)
-        auth_link.setTextInteractionFlags(Qt.TextBrowserInteraction)
+        auth_link.setTextFormat(RichText)
+        auth_link.setTextInteractionFlags(TextBrowserInteraction)
         auth_link.setOpenExternalLinks(True)
         return auth_link
 
